package com.om.service.impl;

import cn.hutool.core.bean.BeanUtil;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.om.entity.dto.DiaLogQueryPageDTO;
import com.om.entity.po.*;
import com.om.entity.vo.DiaLogQueryPageVO;
import com.om.entity.vo.DiaLogQueryVO;
import com.om.mapper.DiagnosticLogMapper;
import com.om.service.*;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.om.utils.Result;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.time.LocalDateTime;
import java.util.ArrayList;
import java.util.List;

/**
 * <p>
 *  服务实现类
 * </p>
 *
 * @author bmmx
 * @since 2024-02-27
 */
@Service
public class DiagnosticLogServiceImpl extends ServiceImpl<DiagnosticLogMapper, DiagnosticLog> implements IDiagnosticLogService {

    @Resource
    private IUserService userService;

    @Resource
    private IBrandService brandService;

    @Resource
    private IClientService clientService;



    @Resource
    private IVciInfoService vciInfoService;

    @Override
    public Result<DiaLogQueryPageVO> getPageList(DiaLogQueryPageDTO dto) {
        //从dto中获取数据
        Integer pageIndex = dto.getPageIndex();
        Integer pageSize = dto.getPageSize();
        String account = dto.getAccount();
        String vciSn = dto.getVciSn();
        LocalDateTime beginTime = dto.getBeginTime();
        LocalDateTime endTime = dto.getEndTime();
        User one = null;
        if (account!=null){
            //根据用户名查询用户
             one = userService.lambdaQuery()
                    .eq(User::getUsername, account)
                    .one();
        }


        VciInfo vciInfo = null;
        if (vciSn!=null){
            //根据vciSn查询VCI
            vciInfo = vciInfoService.lambdaQuery()
                    .eq(VciInfo::getVciNum, vciSn)
                    .one();
        }

        Page<DiagnosticLog> page = this.lambdaQuery()
                .like(one != null, DiagnosticLog::getUserId, one.getId())
                .like(vciInfo != null, DiagnosticLog::getVciId, vciInfo.getId())
                .ge(beginTime != null, DiagnosticLog::getCreateTime, beginTime)
                .le(endTime != null, DiagnosticLog::getCreateTime, endTime)
                .orderByDesc(DiagnosticLog::getCreateTime)
                .page(new Page<>(pageIndex, pageSize));

        DiaLogQueryPageVO vo = new DiaLogQueryPageVO();
        vo.setCurrent((int) page.getCurrent());
        vo.setSize((int) page.getSize());
        vo.setPages((int) page.getPages());
        vo.setTotal((int) page.getTotal());

        if (account!=null||vciSn!=null||beginTime != null||endTime != null){
            vo.setSearchCount(true);
        }

        List<DiagnosticLog> records = page.getRecords();
        List<DiaLogQueryVO> diaLogQueryVOS = new ArrayList<>();
        for (DiagnosticLog record : records) {
            DiaLogQueryVO diaLogQueryVO = BeanUtil.copyProperties(record, DiaLogQueryVO.class);
            User user = userService.getById(record.getUserId());
            diaLogQueryVO.setAccount(user.getUsername());
            Brand brand = brandService.getById(record.getBrandId());
            diaLogQueryVO.setBrand(brand.getBrandCn());

            Client client = clientService.getById(record.getClientId());
            diaLogQueryVO.setClientNum(client.getNumber());

            VciInfo vci = vciInfoService.getById(record.getVciId());
            diaLogQueryVO.setVciSn(vci.getVciNum());

            //todo 车型id vehicleId 查询车型

            diaLogQueryVOS.add(diaLogQueryVO);
        }

        vo.setRecords(diaLogQueryVOS);
        return Result.ok(vo);
    }
}
